// Copyright (c) Argent Stonecutter 2008
// Licensed under the BSD license (at end)

// Symbols in the font texture
string SYMBOLS=" !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`";
// UUID of XYText font texture
key FONT = "b2e7394f-5e54-aa12-6e1c-ef327b6bed9e";
// UUID of default texture (100% transparent)
key BLANK = "8dcd4a48-2d37-4909-9f78-f7a9eb4ef903";

// game parameters
list SIZE_NAMES = ["QUIT","5x5","8x8","10x10","16x16","20x20"];
list SIZES = [ 0, 5, 8, 10, 16, 20 ];
list COUNT_NAMES = ["QUIT","5","10","15","20","25"];
list COUNTS = [ 0, 5, 10, 15, 20, 25];
integer size = 0;
integer count = 0;

//channels
integer CHAT = 668;
integer MAGIC = 1337;

key player;
integer listener = 0;

// Font is a 10xN grid mapping to SYMBOLS (above)
text(integer i) {
    vector offset = <-0.45 + 0.1 * (i % 10), 0.45 - 0.1 * (i / 10), 0.0>;
    llSetPrimitiveParams([PRIM_TEXTURE,ALL_SIDES,FONT,<0.1, 0.1, 0>,offset,0.0]);
}

default
{
    state_entry()
    {
        llSetTimerEvent(1.0);
    }
    state_exit()
    {
        llSetTimerEvent(0);
    }
    timer()
    {
        text(llFloor(llFrand(llStringLength(SYMBOLS))));
    }
    touch_start(integer total_number)
    {
        player = llDetectedKey(0);
        state setup;
    }
}

state reset
{
    state_entry()
    {
        state setup;
    }
}

state setup
{
    state_entry()
    {
        count = -1;
        size = -1;
        if(listener) llListenRemove(listener);
        listener = llListen(CHAT,"",player,"");
        llDialog(player, "Size of playing field?", SIZE_NAMES, CHAT);
        llSetTimerEvent(30);
    }
    state_exit()
    {
        llSetTimerEvent(0);
        if(listener) llListenRemove(listener);
        listener = 0;
    }
    touch_start(integer n)
    {
        key new = llDetectedKey(0);
        if(new != player) llInstantMessage(player, llDetectedName(0)+" is playing.");
        player = new;
        state reset;
    }
    timer()
    {
        llInstantMessage(player, "Sorry, you took too long answering");
        player = NULL_KEY;
    }
    listen(integer chan, string name, key id, string msg)
    {
        if(msg == "QUIT") {
            llInstantMessage(player, "Bubye!");
            llRegionSay(MAGIC, "kitten");
            llSay(0, name+" quitted the game.");
            state default;
        }
        integer i = llListFindList(SIZE_NAMES,[msg]);
        if(i > 0) {
            size = llList2Integer(SIZES, i);
            llDialog(player, "Number of objects?", COUNT_NAMES, CHAT);
            llSetTimerEvent(30);
            return;
        }
        i = llListFindList(COUNT_NAMES,[msg]);
        if(i > 0) {
            count = llList2Integer(COUNTS, i);
            state playing;
        }
    }
}

// Just rez all the objects, pick a random one for kitten in case some smart ass
// turns on SHOW TRANSPARENT as they're rezzing.
state playing
{
    state_entry()
    {
        integer i;
        integer k = llFloor(llFrand(count)); // which object is kitten?
        vector here = llGetPos();
        for(i = 0; i < count; i++) {
            vector there = here;
            there.x += llFrand(size)-size/2;
            there.y += llFrand(size)-size/2;
            there.z += 0.5;
            llRezObject("kitten?",there,ZERO_VECTOR,ZERO_ROTATION,1+(i == k));
        }
        state default;
    }
}

//Copyright (c) 2008, Argent Stonecutter & player
//All rights reserved.
//
//Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//
//    * Redistributions in modifiable form must retain the above copyright notice, this list of conditions and the following disclaimer.
//    * Redistributions in non-modifiable form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//    * Neither the name of Argent Stonecutter nor his player may be used to endorse or promote products derived from this software without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
