// notecard containing messages
string CARD="messages.txt";
// chat channel for informing the wrold kitten has been found
integer MAGIC=1337;
// symbols in the font texture
string SYMBOLS=" !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`";
// UUID of XYText font texture
key FONT = "b2e7394f-5e54-aa12-6e1c-ef327b6bed9e";
// UUID of default texture (100% transparent)
key BLANK = "8dcd4a48-2d37-4909-9f78-f7a9eb4ef903";

string name;
integer line = -1;
key k;
integer countdown;

// Font is a 10xN grid mapping ro SYMBOLS (above)
text(integer i, vector color) {
    vector offset = <-0.45 + 0.1 * (i % 10), 0.45 - 0.1 * (i / 10), 0.0>;
    llSetPrimitiveParams([
        PRIM_TEXTURE,ALL_SIDES,FONT,<0.1, 0.1, 0>,offset,0.0,
        PRIM_COLOR,ALL_SIDES,color,1.0
    ]);
}

// Change my name to first word of string so it doesn't say "kitten? message...", then say rest
// of string as an emote
say(string msg)
{
    msg = llStringTrim(msg, STRING_TRIM);
    string old;
    string new;
    integer i = llSubStringIndex(msg," ");
    if(i == -1) {
        new = msg;
        msg = "";
    } else {
        new = llGetSubString(msg, 0, i-1);
        msg = llGetSubString(msg, i+1, -1);
    }
    old = llGetObjectName();
    llSetObjectName(new);
    llSay(0, "/me "+msg);
    llSetObjectName(old);
}

default
{
    state_entry() // hide!
    {
        llSetText("", ZERO_VECTOR, 0);
        llSetPrimitiveParams([PRIM_TEXTURE,ALL_SIDES,BLANK,<1,1,0>,<0,0,0>,0.0]);
    }
    on_rez(integer p)
    {
        if(p > 1) state kitten;
        else if(p) state notecard;
        else state idle;
    }
}

state idle
{
    state_entry()
    {
        state default;
    }
}

// make sure you're not rezzing right under a player.
state kitten
{
    state_entry()
    {
        name = "kitten";
        llSensor("",NULL_KEY,AGENT,2,PI);
        countdown = 3;
    }
    sensor(integer n)
    {
        if(--countdown < 0) {
            llRegionSay(MAGIC,"kitten");
            say("Oh noes, I can't find a safe place to start!");
            llDie();
        }
        llSetPos(llGetPos()+<llFrand(4)-2,llFrand(4)-2,0>);
        llSensor("",NULL_KEY,AGENT,2,PI);
    }
    no_sensor()
    {
        state setup;
    }
    on_rez(integer p)
    {
        if(p > 1) state kitten;
        else if(p) state notecard;
        else state idle;
    }
}

// read a random line from the messages.txt card
state notecard
{
    state_entry()
    {
        k = llGetNumberOfNotecardLines(CARD);
        line = -1;
    }
    on_rez(integer p)
    {
        if(p > 1) state kitten;
        else if(p) state notecard;
        else state idle;
    }
    
    dataserver(key query, string data)
    {
        if(query != k) return;
        if(line != -1) {
            name = data;
            state setup;
        }
        line = llFloor(llFrand((integer)data));
        k = llGetNotecardLine(CARD, line);
    }
}

// unhide!
state setup
{
    state_entry()
    {
        integer id = llFloor(llFrand(llStringLength(SYMBOLS)-1))+1;
        vector color = <llFrand(1),llFrand(1),llFrand(1)>/2+<.5,.5,.5>;
        text(id, color);
        llSetText(llGetSubString(SYMBOLS,id,id), color, 1);
        llTargetOmega(<0,0,1>,1,1);
        state ready;
    }
    on_rez(integer p)
    {
        if(p > 1) state kitten;
        else if(p) state notecard;
        else state idle;
    }
}

// wait for people to hit me, or the game to end
state ready
{
    state_entry()
    {
        llVolumeDetect(TRUE);
        llListen(MAGIC,"",NULL_KEY,"");
    }
    on_rez(integer p)
    {
        if(p > 1) state kitten;
        else if(p) state notecard;
        else state idle;
    }
    collision_start(integer n)
    {
        integer i;
        for(i = 0; i < 10; i++)
        {
            if(llDetectedOwner(i) == llDetectedKey(i))
            {
                if(name == "kitten") {
                    say(llDetectedName(i)+" found kitten!");
                    llRegionSay(MAGIC, "kitten");
                    llDie();
                } else {
                    say(name);
                    return;
                }
            }
        }
    }
    listen(integer chan,string name,key id,string msg)
    {
        if(chan == MAGIC && msg == "kitten")
            llDie();
    }
}


//Copyright (c) 2008, Argent Stonecutter & player
//All rights reserved.
//
//Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
//
//    * Redistributions in modifiable form must retain the above copyright notice, this list of conditions and the following disclaimer.
//    * Redistributions in non-modifiable form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
//    * Neither the name of Argent Stonecutter nor his player may be used to endorse or promote products derived from this software without specific prior written permission.
//
//THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
